# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/wasmx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/wasmx/v1/wasmx.proto',
  package='injective.wasmx.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1einjective/wasmx/v1/wasmx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\"\xd1\x01\n\x06Params\x12\x1c\n\x14is_execution_enabled\x18\x01 \x01(\x08\x12\x19\n\x11registry_contract\x18\x02 \x01(\t\x12!\n\x19max_begin_block_total_gas\x18\x03 \x01(\x04\x12\x1e\n\x16max_contract_gas_limit\x18\x04 \x01(\x04\x12\x45\n\rmin_gas_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"\xb1\x01\n#ContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\\\n\x1d\x63ontract_registration_request\x18\x03 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb7\x01\n(BatchContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12]\n\x1e\x63ontract_registration_requests\x18\x03 \x03(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xa3\x01\n\x1b\x43ontractRegistrationRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\x41\n\tgas_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0cpin_contract\x18\x04 \x01(\x08\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.wasmx.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_execution_enabled', full_name='injective.wasmx.v1.Params.is_execution_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registry_contract', full_name='injective.wasmx.v1.Params.registry_contract', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_begin_block_total_gas', full_name='injective.wasmx.v1.Params.max_begin_block_total_gas', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_contract_gas_limit', full_name='injective.wasmx.v1.Params.max_contract_gas_limit', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_gas_price', full_name='injective.wasmx.v1.Params.min_gas_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=286,
)


_CONTRACTREGISTRATIONREQUESTPROPOSAL = _descriptor.Descriptor(
  name='ContractRegistrationRequestProposal',
  full_name='injective.wasmx.v1.ContractRegistrationRequestProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.wasmx.v1.ContractRegistrationRequestProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.wasmx.v1.ContractRegistrationRequestProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_registration_request', full_name='injective.wasmx.v1.ContractRegistrationRequestProposal.contract_registration_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=466,
)


_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL = _descriptor.Descriptor(
  name='BatchContractRegistrationRequestProposal',
  full_name='injective.wasmx.v1.BatchContractRegistrationRequestProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.wasmx.v1.BatchContractRegistrationRequestProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.wasmx.v1.BatchContractRegistrationRequestProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_registration_requests', full_name='injective.wasmx.v1.BatchContractRegistrationRequestProposal.contract_registration_requests', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=652,
)


_CONTRACTREGISTRATIONREQUEST = _descriptor.Descriptor(
  name='ContractRegistrationRequest',
  full_name='injective.wasmx.v1.ContractRegistrationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='injective.wasmx.v1.ContractRegistrationRequest.contract_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_limit', full_name='injective.wasmx.v1.ContractRegistrationRequest.gas_limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='injective.wasmx.v1.ContractRegistrationRequest.gas_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pin_contract', full_name='injective.wasmx.v1.ContractRegistrationRequest.pin_contract', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=818,
)

_CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request'].message_type = _CONTRACTREGISTRATIONREQUEST
_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests'].message_type = _CONTRACTREGISTRATIONREQUEST
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['ContractRegistrationRequestProposal'] = _CONTRACTREGISTRATIONREQUESTPROPOSAL
DESCRIPTOR.message_types_by_name['BatchContractRegistrationRequestProposal'] = _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL
DESCRIPTOR.message_types_by_name['ContractRegistrationRequest'] = _CONTRACTREGISTRATIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.wasmx.v1.wasmx_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.Params)
  })
_sym_db.RegisterMessage(Params)

ContractRegistrationRequestProposal = _reflection.GeneratedProtocolMessageType('ContractRegistrationRequestProposal', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTREGISTRATIONREQUESTPROPOSAL,
  '__module__' : 'injective.wasmx.v1.wasmx_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.ContractRegistrationRequestProposal)
  })
_sym_db.RegisterMessage(ContractRegistrationRequestProposal)

BatchContractRegistrationRequestProposal = _reflection.GeneratedProtocolMessageType('BatchContractRegistrationRequestProposal', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL,
  '__module__' : 'injective.wasmx.v1.wasmx_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.BatchContractRegistrationRequestProposal)
  })
_sym_db.RegisterMessage(BatchContractRegistrationRequestProposal)

ContractRegistrationRequest = _reflection.GeneratedProtocolMessageType('ContractRegistrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTREGISTRATIONREQUEST,
  '__module__' : 'injective.wasmx.v1.wasmx_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.ContractRegistrationRequest)
  })
_sym_db.RegisterMessage(ContractRegistrationRequest)


DESCRIPTOR._options = None
_PARAMS.fields_by_name['min_gas_price']._options = None
_PARAMS._options = None
_CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request']._options = None
_CONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests']._options = None
_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
_CONTRACTREGISTRATIONREQUEST.fields_by_name['gas_price']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/slashing/v1beta1/genesis.proto',
  package='cosmos.slashing.v1beta1',
  syntax='proto3',
  serialized_options=b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%cosmos/slashing/v1beta1/genesis.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\"\x85\x02\n\x0cGenesisState\x12\x35\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12Y\n\rsigning_infos\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.SigningInfoB\x1c\xf2\xde\x1f\x14yaml:\"signing_infos\"\xc8\xde\x1f\x00\x12\x63\n\rmissed_blocks\x18\x03 \x03(\x0b\x32..cosmos.slashing.v1beta1.ValidatorMissedBlocksB\x1c\xf2\xde\x1f\x14yaml:\"missed_blocks\"\xc8\xde\x1f\x00\"\x94\x01\n\x0bSigningInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12t\n\x16validator_signing_info\x18\x02 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:\"validator_signing_info\"\"\x83\x01\n\x15ValidatorMissedBlocks\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Y\n\rmissed_blocks\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.MissedBlockB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"missed_blocks\"\",\n\x0bMissedBlock\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x0e\n\x06missed\x18\x02 \x01(\x08\x42/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='cosmos.slashing.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='cosmos.slashing.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signing_infos', full_name='cosmos.slashing.v1beta1.GenesisState.signing_infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"signing_infos\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missed_blocks', full_name='cosmos.slashing.v1beta1.GenesisState.missed_blocks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"missed_blocks\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=390,
)


_SIGNINGINFO = _descriptor.Descriptor(
  name='SigningInfo',
  full_name='cosmos.slashing.v1beta1.SigningInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmos.slashing.v1beta1.SigningInfo.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_signing_info', full_name='cosmos.slashing.v1beta1.SigningInfo.validator_signing_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\035yaml:\"validator_signing_info\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=541,
)


_VALIDATORMISSEDBLOCKS = _descriptor.Descriptor(
  name='ValidatorMissedBlocks',
  full_name='cosmos.slashing.v1beta1.ValidatorMissedBlocks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmos.slashing.v1beta1.ValidatorMissedBlocks.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missed_blocks', full_name='cosmos.slashing.v1beta1.ValidatorMissedBlocks.missed_blocks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\024yaml:\"missed_blocks\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=675,
)


_MISSEDBLOCK = _descriptor.Descriptor(
  name='MissedBlock',
  full_name='cosmos.slashing.v1beta1.MissedBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='cosmos.slashing.v1beta1.MissedBlock.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missed', full_name='cosmos.slashing.v1beta1.MissedBlock.missed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=721,
)

_GENESISSTATE.fields_by_name['params'].message_type = cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2._PARAMS
_GENESISSTATE.fields_by_name['signing_infos'].message_type = _SIGNINGINFO
_GENESISSTATE.fields_by_name['missed_blocks'].message_type = _VALIDATORMISSEDBLOCKS
_SIGNINGINFO.fields_by_name['validator_signing_info'].message_type = cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2._VALIDATORSIGNINGINFO
_VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks'].message_type = _MISSEDBLOCK
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['SigningInfo'] = _SIGNINGINFO
DESCRIPTOR.message_types_by_name['ValidatorMissedBlocks'] = _VALIDATORMISSEDBLOCKS
DESCRIPTOR.message_types_by_name['MissedBlock'] = _MISSEDBLOCK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

SigningInfo = _reflection.GeneratedProtocolMessageType('SigningInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGINFO,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.SigningInfo)
  })
_sym_db.RegisterMessage(SigningInfo)

ValidatorMissedBlocks = _reflection.GeneratedProtocolMessageType('ValidatorMissedBlocks', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORMISSEDBLOCKS,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.ValidatorMissedBlocks)
  })
_sym_db.RegisterMessage(ValidatorMissedBlocks)

MissedBlock = _reflection.GeneratedProtocolMessageType('MissedBlock', (_message.Message,), {
  'DESCRIPTOR' : _MISSEDBLOCK,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.MissedBlock)
  })
_sym_db.RegisterMessage(MissedBlock)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_GENESISSTATE.fields_by_name['signing_infos']._options = None
_GENESISSTATE.fields_by_name['missed_blocks']._options = None
_SIGNINGINFO.fields_by_name['validator_signing_info']._options = None
_VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/types/params.proto',
  package='tendermint.types',
  syntax='proto3',
  serialized_options=b'Z7github.com/tendermint/tendermint/proto/tendermint/types\250\342\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dtendermint/types/params.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf3\x01\n\x0f\x43onsensusParams\x12\x32\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1d.tendermint.types.BlockParamsB\x04\xc8\xde\x1f\x00\x12\x38\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParamsB\x04\xc8\xde\x1f\x00\x12:\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParamsB\x04\xc8\xde\x1f\x00\x12\x36\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParamsB\x04\xc8\xde\x1f\x00\"G\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\x12\x14\n\x0ctime_iota_ms\x18\x03 \x01(\x03\"~\n\x0e\x45videnceParams\x12\x1a\n\x12max_age_num_blocks\x18\x01 \x01(\x03\x12=\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x11\n\tmax_bytes\x18\x03 \x01(\x03\"2\n\x0fValidatorParams\x12\x15\n\rpub_key_types\x18\x01 \x03(\t:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\".\n\rVersionParams\x12\x13\n\x0b\x61pp_version\x18\x01 \x01(\x04:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\">\n\x0cHashedParams\x12\x17\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03\x12\x15\n\rblock_max_gas\x18\x02 \x01(\x03\x42=Z7github.com/tendermint/tendermint/proto/tendermint/types\xa8\xe2\x1e\x01\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_CONSENSUSPARAMS = _descriptor.Descriptor(
  name='ConsensusParams',
  full_name='tendermint.types.ConsensusParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='tendermint.types.ConsensusParams.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evidence', full_name='tendermint.types.ConsensusParams.evidence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='tendermint.types.ConsensusParams.validator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='tendermint.types.ConsensusParams.version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=349,
)


_BLOCKPARAMS = _descriptor.Descriptor(
  name='BlockParams',
  full_name='tendermint.types.BlockParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_bytes', full_name='tendermint.types.BlockParams.max_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_gas', full_name='tendermint.types.BlockParams.max_gas', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_iota_ms', full_name='tendermint.types.BlockParams.time_iota_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=422,
)


_EVIDENCEPARAMS = _descriptor.Descriptor(
  name='EvidenceParams',
  full_name='tendermint.types.EvidenceParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_age_num_blocks', full_name='tendermint.types.EvidenceParams.max_age_num_blocks', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_age_duration', full_name='tendermint.types.EvidenceParams.max_age_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\230\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes', full_name='tendermint.types.EvidenceParams.max_bytes', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=550,
)


_VALIDATORPARAMS = _descriptor.Descriptor(
  name='ValidatorParams',
  full_name='tendermint.types.ValidatorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key_types', full_name='tendermint.types.ValidatorParams.pub_key_types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\270\240\037\001\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=602,
)


_VERSIONPARAMS = _descriptor.Descriptor(
  name='VersionParams',
  full_name='tendermint.types.VersionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_version', full_name='tendermint.types.VersionParams.app_version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\270\240\037\001\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=650,
)


_HASHEDPARAMS = _descriptor.Descriptor(
  name='HashedParams',
  full_name='tendermint.types.HashedParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_max_bytes', full_name='tendermint.types.HashedParams.block_max_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_max_gas', full_name='tendermint.types.HashedParams.block_max_gas', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=714,
)

_CONSENSUSPARAMS.fields_by_name['block'].message_type = _BLOCKPARAMS
_CONSENSUSPARAMS.fields_by_name['evidence'].message_type = _EVIDENCEPARAMS
_CONSENSUSPARAMS.fields_by_name['validator'].message_type = _VALIDATORPARAMS
_CONSENSUSPARAMS.fields_by_name['version'].message_type = _VERSIONPARAMS
_EVIDENCEPARAMS.fields_by_name['max_age_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ConsensusParams'] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['BlockParams'] = _BLOCKPARAMS
DESCRIPTOR.message_types_by_name['EvidenceParams'] = _EVIDENCEPARAMS
DESCRIPTOR.message_types_by_name['ValidatorParams'] = _VALIDATORPARAMS
DESCRIPTOR.message_types_by_name['VersionParams'] = _VERSIONPARAMS
DESCRIPTOR.message_types_by_name['HashedParams'] = _HASHEDPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConsensusParams = _reflection.GeneratedProtocolMessageType('ConsensusParams', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.ConsensusParams)
  })
_sym_db.RegisterMessage(ConsensusParams)

BlockParams = _reflection.GeneratedProtocolMessageType('BlockParams', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.BlockParams)
  })
_sym_db.RegisterMessage(BlockParams)

EvidenceParams = _reflection.GeneratedProtocolMessageType('EvidenceParams', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCEPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.EvidenceParams)
  })
_sym_db.RegisterMessage(EvidenceParams)

ValidatorParams = _reflection.GeneratedProtocolMessageType('ValidatorParams', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.ValidatorParams)
  })
_sym_db.RegisterMessage(ValidatorParams)

VersionParams = _reflection.GeneratedProtocolMessageType('VersionParams', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.VersionParams)
  })
_sym_db.RegisterMessage(VersionParams)

HashedParams = _reflection.GeneratedProtocolMessageType('HashedParams', (_message.Message,), {
  'DESCRIPTOR' : _HASHEDPARAMS,
  '__module__' : 'tendermint.types.params_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.HashedParams)
  })
_sym_db.RegisterMessage(HashedParams)


DESCRIPTOR._options = None
_CONSENSUSPARAMS.fields_by_name['block']._options = None
_CONSENSUSPARAMS.fields_by_name['evidence']._options = None
_CONSENSUSPARAMS.fields_by_name['validator']._options = None
_CONSENSUSPARAMS.fields_by_name['version']._options = None
_EVIDENCEPARAMS.fields_by_name['max_age_duration']._options = None
_VALIDATORPARAMS._options = None
_VERSIONPARAMS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/oracle.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x0e\n\x06Params:\x04\xe8\xa0\x1f\x01\"m\n\nOracleInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\x0boracle_type\x18\x02 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x14\n\x0cscale_factor\x18\x03 \x01(\r\"\xba\x01\n\x13\x43hainlinkPriceState\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12?\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xc9\x01\n\x0e\x42\x61ndPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12<\n\x04rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x03 \x01(\x04\x12\x12\n\nrequest_ID\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"z\n\x0ePriceFeedState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12\x39\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\x12\x10\n\x08relayers\x18\x04 \x03(\t\"2\n\x0cProviderInfo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x10\n\x08relayers\x18\x02 \x03(\t\"\x9b\x01\n\rProviderState\x12=\n\rprovider_info\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.ProviderInfo\x12K\n\x15provider_price_states\x18\x02 \x03(\x0b\x32,.injective.oracle.v1beta1.ProviderPriceState\"Y\n\x12ProviderPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x33\n\x05state\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\",\n\rPriceFeedInfo\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\"O\n\x0ePriceFeedPrice\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x92\x01\n\x12\x43oinbasePriceState\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xa8\x01\n\nPriceState\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\x82\x02\n\x11\x42\x61ndOracleRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x04\x12\x18\n\x10oracle_script_id\x18\x02 \x01(\x03\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\"\x8d\x01\n\rBandIBCParams\x12\x18\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14ibc_request_interval\x18\x02 \x01(\x03\x12\x1a\n\x12ibc_source_channel\x18\x03 \x01(\t\x12\x13\n\x0bibc_version\x18\x04 \x01(\t\x12\x13\n\x0bibc_port_id\x18\x05 \x01(\t\"r\n\x14SymbolPriceTimestamp\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"d\n\x13LastPriceTimestamps\x12M\n\x15last_price_timestamps\x18\x01 \x03(\x0b\x32..injective.oracle.v1beta1.SymbolPriceTimestamp\"\x9c\x01\n\x0cPriceRecords\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x43\n\x14latest_price_records\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecord\"_\n\x0bPriceRecord\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xbf\x03\n\x12MetadataStatistics\x12\x13\n\x0bgroup_count\x18\x01 \x01(\r\x12\x1b\n\x13records_sample_size\x18\x02 \x01(\r\x12<\n\x04mean\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12<\n\x04twap\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x17\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03\x12\x16\n\x0elast_timestamp\x18\x06 \x01(\x03\x12\x41\n\tmin_price\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x41\n\tmax_price\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cmedian_price\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00*\x9f\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\n\x12\x0c\n\x08Provider\x10\x0b\x42NZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_ORACLETYPE = _descriptor.EnumDescriptor(
  name='OracleType',
  full_name='injective.oracle.v1beta1.OracleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Band', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PriceFeed', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Coinbase', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Chainlink', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Razor', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Dia', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API3', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Uma', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Pyth', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BandIBC', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Provider', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2843,
  serialized_end=3002,
)
_sym_db.RegisterEnumDescriptor(_ORACLETYPE)

OracleType = enum_type_wrapper.EnumTypeWrapper(_ORACLETYPE)
Unspecified = 0
Band = 1
PriceFeed = 2
Coinbase = 3
Chainlink = 4
Razor = 5
Dia = 6
API3 = 7
Uma = 8
Pyth = 9
BandIBC = 10
Provider = 11



_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.oracle.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=135,
)


_ORACLEINFO = _descriptor.Descriptor(
  name='OracleInfo',
  full_name='injective.oracle.v1beta1.OracleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.OracleInfo.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.oracle.v1beta1.OracleInfo.oracle_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_factor', full_name='injective.oracle.v1beta1.OracleInfo.scale_factor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=246,
)


_CHAINLINKPRICESTATE = _descriptor.Descriptor(
  name='ChainlinkPriceState',
  full_name='injective.oracle.v1beta1.ChainlinkPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.oracle.v1beta1.ChainlinkPriceState.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.oracle.v1beta1.ChainlinkPriceState.answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.ChainlinkPriceState.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.ChainlinkPriceState.price_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=435,
)


_BANDPRICESTATE = _descriptor.Descriptor(
  name='BandPriceState',
  full_name='injective.oracle.v1beta1.BandPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.BandPriceState.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='injective.oracle.v1beta1.BandPriceState.rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.BandPriceState.resolve_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_ID', full_name='injective.oracle.v1beta1.BandPriceState.request_ID', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.BandPriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=639,
)


_PRICEFEEDSTATE = _descriptor.Descriptor(
  name='PriceFeedState',
  full_name='injective.oracle.v1beta1.PriceFeedState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedState.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedState.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.PriceFeedState.price_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.PriceFeedState.relayers', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=763,
)


_PROVIDERINFO = _descriptor.Descriptor(
  name='ProviderInfo',
  full_name='injective.oracle.v1beta1.ProviderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.ProviderInfo.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.ProviderInfo.relayers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=815,
)


_PROVIDERSTATE = _descriptor.Descriptor(
  name='ProviderState',
  full_name='injective.oracle.v1beta1.ProviderState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_info', full_name='injective.oracle.v1beta1.ProviderState.provider_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_price_states', full_name='injective.oracle.v1beta1.ProviderState.provider_price_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=973,
)


_PROVIDERPRICESTATE = _descriptor.Descriptor(
  name='ProviderPriceState',
  full_name='injective.oracle.v1beta1.ProviderPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.ProviderPriceState.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.oracle.v1beta1.ProviderPriceState.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1064,
)


_PRICEFEEDINFO = _descriptor.Descriptor(
  name='PriceFeedInfo',
  full_name='injective.oracle.v1beta1.PriceFeedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedInfo.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedInfo.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1110,
)


_PRICEFEEDPRICE = _descriptor.Descriptor(
  name='PriceFeedPrice',
  full_name='injective.oracle.v1beta1.PriceFeedPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceFeedPrice.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1191,
)


_COINBASEPRICESTATE = _descriptor.Descriptor(
  name='CoinbasePriceState',
  full_name='injective.oracle.v1beta1.CoinbasePriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='injective.oracle.v1beta1.CoinbasePriceState.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.CoinbasePriceState.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='injective.oracle.v1beta1.CoinbasePriceState.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective.oracle.v1beta1.CoinbasePriceState.value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.CoinbasePriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1340,
)


_PRICESTATE = _descriptor.Descriptor(
  name='PriceState',
  full_name='injective.oracle.v1beta1.PriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceState.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_price', full_name='injective.oracle.v1beta1.PriceState.cumulative_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.PriceState.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1511,
)


_BANDORACLEREQUEST = _descriptor.Descriptor(
  name='BandOracleRequest',
  full_name='injective.oracle.v1beta1.BandOracleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.BandOracleRequest.request_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='injective.oracle.v1beta1.BandOracleRequest.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.BandOracleRequest.symbols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='injective.oracle.v1beta1.BandOracleRequest.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='injective.oracle.v1beta1.BandOracleRequest.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='injective.oracle.v1beta1.BandOracleRequest.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.prepare_gas', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.execute_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1772,
)


_BANDIBCPARAMS = _descriptor.Descriptor(
  name='BandIBCParams',
  full_name='injective.oracle.v1beta1.BandIBCParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='band_ibc_enabled', full_name='injective.oracle.v1beta1.BandIBCParams.band_ibc_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_request_interval', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_request_interval', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_source_channel', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_source_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_version', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_port_id', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_port_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=1916,
)


_SYMBOLPRICETIMESTAMP = _descriptor.Descriptor(
  name='SymbolPriceTimestamp',
  full_name='injective.oracle.v1beta1.SymbolPriceTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.oracle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.symbol_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=2032,
)


_LASTPRICETIMESTAMPS = _descriptor.Descriptor(
  name='LastPriceTimestamps',
  full_name='injective.oracle.v1beta1.LastPriceTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_price_timestamps', full_name='injective.oracle.v1beta1.LastPriceTimestamps.last_price_timestamps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2134,
)


_PRICERECORDS = _descriptor.Descriptor(
  name='PriceRecords',
  full_name='injective.oracle.v1beta1.PriceRecords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle', full_name='injective.oracle.v1beta1.PriceRecords.oracle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='injective.oracle.v1beta1.PriceRecords.symbol_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_price_records', full_name='injective.oracle.v1beta1.PriceRecords.latest_price_records', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2137,
  serialized_end=2293,
)


_PRICERECORD = _descriptor.Descriptor(
  name='PriceRecord',
  full_name='injective.oracle.v1beta1.PriceRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.PriceRecord.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceRecord.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2295,
  serialized_end=2390,
)


_METADATASTATISTICS = _descriptor.Descriptor(
  name='MetadataStatistics',
  full_name='injective.oracle.v1beta1.MetadataStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_count', full_name='injective.oracle.v1beta1.MetadataStatistics.group_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records_sample_size', full_name='injective.oracle.v1beta1.MetadataStatistics.records_sample_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='injective.oracle.v1beta1.MetadataStatistics.mean', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twap', full_name='injective.oracle.v1beta1.MetadataStatistics.twap', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_timestamp', full_name='injective.oracle.v1beta1.MetadataStatistics.first_timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_timestamp', full_name='injective.oracle.v1beta1.MetadataStatistics.last_timestamp', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price', full_name='injective.oracle.v1beta1.MetadataStatistics.min_price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_price', full_name='injective.oracle.v1beta1.MetadataStatistics.max_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median_price', full_name='injective.oracle.v1beta1.MetadataStatistics.median_price', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2393,
  serialized_end=2840,
)

_ORACLEINFO.fields_by_name['oracle_type'].enum_type = _ORACLETYPE
_CHAINLINKPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_BANDPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_PRICEFEEDSTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_PROVIDERSTATE.fields_by_name['provider_info'].message_type = _PROVIDERINFO
_PROVIDERSTATE.fields_by_name['provider_price_states'].message_type = _PROVIDERPRICESTATE
_PROVIDERPRICESTATE.fields_by_name['state'].message_type = _PRICESTATE
_COINBASEPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_BANDORACLEREQUEST.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_SYMBOLPRICETIMESTAMP.fields_by_name['oracle'].enum_type = _ORACLETYPE
_LASTPRICETIMESTAMPS.fields_by_name['last_price_timestamps'].message_type = _SYMBOLPRICETIMESTAMP
_PRICERECORDS.fields_by_name['oracle'].enum_type = _ORACLETYPE
_PRICERECORDS.fields_by_name['latest_price_records'].message_type = _PRICERECORD
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['OracleInfo'] = _ORACLEINFO
DESCRIPTOR.message_types_by_name['ChainlinkPriceState'] = _CHAINLINKPRICESTATE
DESCRIPTOR.message_types_by_name['BandPriceState'] = _BANDPRICESTATE
DESCRIPTOR.message_types_by_name['PriceFeedState'] = _PRICEFEEDSTATE
DESCRIPTOR.message_types_by_name['ProviderInfo'] = _PROVIDERINFO
DESCRIPTOR.message_types_by_name['ProviderState'] = _PROVIDERSTATE
DESCRIPTOR.message_types_by_name['ProviderPriceState'] = _PROVIDERPRICESTATE
DESCRIPTOR.message_types_by_name['PriceFeedInfo'] = _PRICEFEEDINFO
DESCRIPTOR.message_types_by_name['PriceFeedPrice'] = _PRICEFEEDPRICE
DESCRIPTOR.message_types_by_name['CoinbasePriceState'] = _COINBASEPRICESTATE
DESCRIPTOR.message_types_by_name['PriceState'] = _PRICESTATE
DESCRIPTOR.message_types_by_name['BandOracleRequest'] = _BANDORACLEREQUEST
DESCRIPTOR.message_types_by_name['BandIBCParams'] = _BANDIBCPARAMS
DESCRIPTOR.message_types_by_name['SymbolPriceTimestamp'] = _SYMBOLPRICETIMESTAMP
DESCRIPTOR.message_types_by_name['LastPriceTimestamps'] = _LASTPRICETIMESTAMPS
DESCRIPTOR.message_types_by_name['PriceRecords'] = _PRICERECORDS
DESCRIPTOR.message_types_by_name['PriceRecord'] = _PRICERECORD
DESCRIPTOR.message_types_by_name['MetadataStatistics'] = _METADATASTATISTICS
DESCRIPTOR.enum_types_by_name['OracleType'] = _ORACLETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

OracleInfo = _reflection.GeneratedProtocolMessageType('OracleInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.OracleInfo)
  })
_sym_db.RegisterMessage(OracleInfo)

ChainlinkPriceState = _reflection.GeneratedProtocolMessageType('ChainlinkPriceState', (_message.Message,), {
  'DESCRIPTOR' : _CHAINLINKPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ChainlinkPriceState)
  })
_sym_db.RegisterMessage(ChainlinkPriceState)

BandPriceState = _reflection.GeneratedProtocolMessageType('BandPriceState', (_message.Message,), {
  'DESCRIPTOR' : _BANDPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandPriceState)
  })
_sym_db.RegisterMessage(BandPriceState)

PriceFeedState = _reflection.GeneratedProtocolMessageType('PriceFeedState', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDSTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedState)
  })
_sym_db.RegisterMessage(PriceFeedState)

ProviderInfo = _reflection.GeneratedProtocolMessageType('ProviderInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderInfo)
  })
_sym_db.RegisterMessage(ProviderInfo)

ProviderState = _reflection.GeneratedProtocolMessageType('ProviderState', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderState)
  })
_sym_db.RegisterMessage(ProviderState)

ProviderPriceState = _reflection.GeneratedProtocolMessageType('ProviderPriceState', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderPriceState)
  })
_sym_db.RegisterMessage(ProviderPriceState)

PriceFeedInfo = _reflection.GeneratedProtocolMessageType('PriceFeedInfo', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedInfo)
  })
_sym_db.RegisterMessage(PriceFeedInfo)

PriceFeedPrice = _reflection.GeneratedProtocolMessageType('PriceFeedPrice', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDPRICE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedPrice)
  })
_sym_db.RegisterMessage(PriceFeedPrice)

CoinbasePriceState = _reflection.GeneratedProtocolMessageType('CoinbasePriceState', (_message.Message,), {
  'DESCRIPTOR' : _COINBASEPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.CoinbasePriceState)
  })
_sym_db.RegisterMessage(CoinbasePriceState)

PriceState = _reflection.GeneratedProtocolMessageType('PriceState', (_message.Message,), {
  'DESCRIPTOR' : _PRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceState)
  })
_sym_db.RegisterMessage(PriceState)

BandOracleRequest = _reflection.GeneratedProtocolMessageType('BandOracleRequest', (_message.Message,), {
  'DESCRIPTOR' : _BANDORACLEREQUEST,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandOracleRequest)
  })
_sym_db.RegisterMessage(BandOracleRequest)

BandIBCParams = _reflection.GeneratedProtocolMessageType('BandIBCParams', (_message.Message,), {
  'DESCRIPTOR' : _BANDIBCPARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandIBCParams)
  })
_sym_db.RegisterMessage(BandIBCParams)

SymbolPriceTimestamp = _reflection.GeneratedProtocolMessageType('SymbolPriceTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLPRICETIMESTAMP,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SymbolPriceTimestamp)
  })
_sym_db.RegisterMessage(SymbolPriceTimestamp)

LastPriceTimestamps = _reflection.GeneratedProtocolMessageType('LastPriceTimestamps', (_message.Message,), {
  'DESCRIPTOR' : _LASTPRICETIMESTAMPS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.LastPriceTimestamps)
  })
_sym_db.RegisterMessage(LastPriceTimestamps)

PriceRecords = _reflection.GeneratedProtocolMessageType('PriceRecords', (_message.Message,), {
  'DESCRIPTOR' : _PRICERECORDS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceRecords)
  })
_sym_db.RegisterMessage(PriceRecords)

PriceRecord = _reflection.GeneratedProtocolMessageType('PriceRecord', (_message.Message,), {
  'DESCRIPTOR' : _PRICERECORD,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceRecord)
  })
_sym_db.RegisterMessage(PriceRecord)

MetadataStatistics = _reflection.GeneratedProtocolMessageType('MetadataStatistics', (_message.Message,), {
  'DESCRIPTOR' : _METADATASTATISTICS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MetadataStatistics)
  })
_sym_db.RegisterMessage(MetadataStatistics)


DESCRIPTOR._options = None
_PARAMS._options = None
_CHAINLINKPRICESTATE.fields_by_name['answer']._options = None
_CHAINLINKPRICESTATE.fields_by_name['price_state']._options = None
_BANDPRICESTATE.fields_by_name['rate']._options = None
_BANDPRICESTATE.fields_by_name['price_state']._options = None
_PRICEFEEDPRICE.fields_by_name['price']._options = None
_COINBASEPRICESTATE.fields_by_name['price_state']._options = None
_PRICESTATE.fields_by_name['price']._options = None
_PRICESTATE.fields_by_name['cumulative_price']._options = None
_BANDORACLEREQUEST.fields_by_name['fee_limit']._options = None
_PRICERECORD.fields_by_name['price']._options = None
_METADATASTATISTICS.fields_by_name['mean']._options = None
_METADATASTATISTICS.fields_by_name['twap']._options = None
_METADATASTATISTICS.fields_by_name['min_price']._options = None
_METADATASTATISTICS.fields_by_name['max_price']._options = None
_METADATASTATISTICS.fields_by_name['median_price']._options = None
# @@protoc_insertion_point(module_scope)
